==> zuspec_parser-0.0.1.10635783205-cp311-cp311-macosx_14_0_universal2.whl: zsp_parser/share/include/zsp/ast/IActivityLabeledScope.h <==
/****************************************************************************
 * IActivityLabeledScope.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/
#pragma once
#include <stdint.h>
#include <unordered_map>
#include <memory>
#include <set>
#include <string>
#include <vector>
#include "zsp/ast/impl/UP.h"
#include "zsp/ast/IVisitor.h"
#include "zsp/ast/IScope.h"

namespace zsp {
namespace ast {

class IScope;
using IScopeUP=UP<IScope>;
typedef std::shared_ptr<IScope> IScopeSP;
class IExprId;
using IExprIdUP=UP<IExprId>;
typedef std::shared_ptr<IExprId> IExprIdSP;
class IActivityLabeledScope;
using IActivityLabeledScopeUP=UP<IActivityLabeledScope>;
class IActivityLabeledScope : public virtual IScope {
public:
    
    virtual ~IActivityLabeledScope() { }
    
    
    virtual IExprId *getLabel() const = 0;
    
    virtual void setLabel(IExprId *v, bool own=true) = 0;
};
    
    } // namespace zsp
    } // namespace ast

==> zuspec_parser-0.0.1.11431519164-cp311-cp311-macosx_14_0_universal2.whl: zsp_parser/share/include/zsp/ast/IActivityLabeledScope.h <==
/****************************************************************************
 * IActivityLabeledScope.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/
#pragma once
#include <stdint.h>
#include <unordered_map>
#include <memory>
#include <set>
#include <string>
#include <vector>
#include "zsp/ast/impl/UP.h"
#include "zsp/ast/IVisitor.h"
#include "zsp/ast/ISymbolScope.h"

namespace zsp {
namespace ast {

class ISymbolScope;
using ISymbolScopeUP=UP<ISymbolScope>;
typedef std::shared_ptr<ISymbolScope> ISymbolScopeSP;
class IExprId;
using IExprIdUP=UP<IExprId>;
typedef std::shared_ptr<IExprId> IExprIdSP;
class IActivityLabeledScope;
using IActivityLabeledScopeUP=UP<IActivityLabeledScope>;
class IActivityLabeledScope : public virtual ISymbolScope {
public:
    
    virtual ~IActivityLabeledScope() { }
    
    
    virtual IExprId *getLabel() const = 0;
    
    virtual void setLabel(IExprId *v, bool own=true) = 0;
};
    
    } // namespace zsp
    } // namespace ast
